==> prestashop-1.3.2.3.tbz: www/prestashop/translations/fr/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF_invoicee0036b67b754e9f6442f9f9e6b200c33'] = 'Retour n°';
$_LANGPDF['PDF_invoice77c3e447f60541a1c346a08134078c7f'] = 'Avoir n°';
$_LANGPDF['PDF_invoicecb5efbba6a6babef9082ca6976928ca7'] = 'Bon de livraison n°';
$_LANGPDF['PDF_invoicefe4da50838bb10dcbf1bf8dcd9b12ab5'] = 'Facture n°';
$_LANGPDF['PDF_invoiceba160acb58001c904c57507da3689265'] = 'Commande n°';
$_LANGPDF['PDF_invoice8dae339c20973fe3fcdeb5f2e8e8f894'] = 'Une version électronique est conservée sur votre compte. Pour y accéder, identifiez-vous sur le site';
$_LANGPDF['PDF_invoice15b57bef332e7e0327d89fe93711a954'] = 'Une version électronique est conservée sur votre compte. Pour y accéder, identifiez-vous sur le site';
$_LANGPDF['PDF_invoicef14e57cfbfd08615bbb665cb803f46b1'] = 'avec vos identifiants (créés lors de votre première commande).';
$_LANGPDF['PDF_invoice808a04117534f9dfb63b9accd7efc609'] = 'Siège social';
$_LANGPDF['PDF_invoice2babe53026309ed1bc4d26626dbaf9b3'] = 'Détails :';
$_LANGPDF['PDF_invoicea54cedc1e053a70d4a6319feccf531ca'] = 'Téléphone :';
$_LANGPDF['PDF_invoiced98a07f84921b24ee30f86fd8cd85c3c'] = 'du';
$_LANGPDF['PDF_invoice88be9ea838e21273267409d76af3b284'] = 'Nous avons bien enregistré votre demande de retour.';
$_LANGPDF['PDF_invoicee209d63b7260d6ce2c7873df4c2ee73c'] = 'Nous vous rappelons que votre colis doit nous être retourné dans les';
$_LANGPDF['PDF_invoice1926fda32a52ec84f205a65b98f8bbb8'] = 'jours après réception de votre commande.';
$_LANGPDF['PDF_invoice3d2f834cf879baebfdbe52c1c14d9d53'] = 'Liste des produits faisant l\'objet d\'un retour :';
$_LANGPDF['PDF_invoice9fad4fa5f3fa5caad9b506bbdd9f35d4'] = 'Votre n° de retour :';
$_LANGPDF['PDF_invoicefb902bc4807c307b9309f2b528b96f2b'] = 'RET';
$_LANGPDF['PDF_invoice80fb5b9230a258ff2e249f1148e726fc'] = 'Merci de faire figurer ce numéro sur votre colis de retour.';
$_LANGPDF['PDF_invoicefbbd47b7e45c0ad3fe0bf70539b5a2d4'] = 'RAPPEL :';
$_LANGPDF['PDF_invoicea3852e23346f6f1e29e1683991690af3'] = '- Tous les produits doivent être retournés dans leur emballage et leur état d\'origine.';
$_LANGPDF['PDF_invoice0e9a828e54995e48083a072205493fb4'] = '- Veuillez imprimer ce document et le glisser dans votre colis.';
$_LANGPDF['PDF_invoicead500469c8dc258dcebb89c9efe15de7'] = '- Le paquet devra être envoyé à l\'adresse suivante :';
$_LANGPDF['PDF_invoice8a060230ab24c7f6a92f3e2b06ed171a'] = 'Dès réception de votre colis nous procéderons alors au remboursement du montant de votre commande et vous en informerons par mail.';
$_LANGPDF['PDF_invoice2d0620950a4d96ae301ba7a98e528714'] = 'Merci de nous contacter pour toutes questions.';
$_LANGPDF['PDF_invoice25e12a86579549b9f88117615eb05e4b'] = 'Si les conditions de retour listées ci-dessus n\'étaient pas respectées,';
$_LANGPDF['PDF_invoicec896fe3f3895e8ef54194eec601b8f3c'] = 'nous nous réservons le droit de refuser votre colis ou votre remboursement.';
$_LANGPDF['PDF_invoiceb5a7adde1af5c87d7fd797b6245c2a39'] = 'Description';
$_LANGPDF['PDF_invoice63d5049791d9d79d86e9a108b0a999ca'] = 'Référence';
$_LANGPDF['PDF_invoice03ab340b3f99e03cff9e84314ead38c0'] = 'Qté';
$_LANGPDF['PDF_invoice396124314c5fd1fa5bf463274896dc80'] = 'Pas de méthode d\'affichage de prix défini pour ce groupe d\'utilisateur';
$_LANGPDF['PDF_invoice065ab3a28ca4f16f55f103adc7d0226f'] = 'Livraison';
$_LANGPDF['PDF_invoice6bdf2efe1a99072849d4e87baee37dbe'] = 'Facturation';
$_LANGPDF['PDF_invoice60da3bd6867e3952ef0057a0772ea885'] = 'Numéro d\'indentification fiscale:';
$_LANGPDF['PDF_invoiced1228f5476d15142b1358ae4b5fa2454'] = 'Commande n°';
$_LANGPDF['PDF_invoicef8617a92ba0a0a4eabee724eab7c9f48'] = 'Transporteur :';
$_LANGPDF['PDF_invoicec1f6368d15f7c13c4e5e8f70c68c747f'] = 'Méthode de paiement :';
$_LANGPDF['PDF_invoicea3a79b28bc45b7fd393effd056b917e1'] = 'Date d\'expédition :';
$_LANGPDF['PDF_invoice115dfa9ced2cf136ae677b9a389a5e60'] = 'Emballage cadeau';
$_LANGPDF['PDF_invoice2370a4958c4ebe6d6c8045cd49a6b392'] = 'Total produits HT';
$_LANGPDF['PDF_invoiceebaee01719541f61281c16ba22ebbfde'] = 'Total produits TTC';
$_LANGPDF['PDF_invoicea0eb2cd0b3deb5444102e9a82edae11e'] = 'Total produits';
$_LANGPDF['PDF_invoicef3e545fccad720e197b9ca3b8b658440'] = 'Totals réductions TTC';
$_LANGPDF['PDF_invoice7a5b34426b4672759796f035bbc2674e'] = 'Total emballage';
$_LANGPDF['PDF_invoicef4e8b53a114e5a17d051ab84d326cae5'] = 'Total livraison';
$_LANGPDF['PDF_invoice96b0141273eabab320119c467cdcaf17'] = 'Total';
$_LANGPDF['PDF_invoice54732c5d0a3f0d597312b0ee55d71fca'] = 'TTC';
$_LANGPDF['PDF_invoiceac5831c7ec2fed92c7bb73e9962003a4'] = 'HT';
$_LANGPDF['PDF_invoice7d3548c5b974fa710296c1b3f5564753'] = 'Eco-participation';
$_LANGPDF['PDF_invoiceafd42dfebce46ec93972b2e0cbb8b83f'] = 'Prix unitaire';
$_LANGPDF['PDF_invoicec2808546f3e14d267d798f4e0e6f102e'] = 'Personnalisé';
$_LANGPDF['PDF_invoicea1e7379abfdbc3b8e03506e5489c6110'] = 'Réduction :';
$_LANGPDF['PDF_invoice42c26bf38ece1dcd27aca8c6f8c076ed'] = 'Détails de taxe';
$_LANGPDF['PDF_invoicea7fa76ae71664800f8994ad52581e3c2'] = '% de la taxe';
$_LANGPDF['PDF_invoicecd6576cc33506a6c44e2debbde5c14d9'] = 'Total HT';
$_LANGPDF['PDF_invoiceb602e0d0c6a72053d0a5be60cb2f8126'] = 'Taxe totale';
$_LANGPDF['PDF_invoiceae5c2883df7651730799e1036984a6a3'] = 'Total TTC';
$_LANGPDF['PDF_invoice068f80c7519d0528fb08e82137a72131'] = 'Produits';
$_LANGPDF['PDF_invoice914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_LANGPDF['PDF_invoiceba794350deb07c0c96fe73bd12239059'] = 'Emballage';
$_LANGPDF['PDF_invoice6f3455d187a23443796efdcbe044096b'] = 'Aucune taxe';

?>

==> prestashop-1.4.9.0.tbz: www/prestashop/translations/fr/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF_invoicee0036b67b754e9f6442f9f9e6b200c33'] = 'Retour n°';
$_LANGPDF['PDF_invoice77c3e447f60541a1c346a08134078c7f'] = 'Avoir n°';
$_LANGPDF['PDF_invoicecb5efbba6a6babef9082ca6976928ca7'] = 'Bon de livraison n°';
$_LANGPDF['PDF_invoicefe4da50838bb10dcbf1bf8dcd9b12ab5'] = 'Facture n°';
$_LANGPDF['PDF_invoiceba160acb58001c904c57507da3689265'] = 'Commande n°';
$_LANGPDF['PDF_invoice808a04117534f9dfb63b9accd7efc609'] = 'Siège social';
$_LANGPDF['PDF_invoicea54cedc1e053a70d4a6319feccf531ca'] = 'Téléphone :';
$_LANGPDF['PDF_invoice2babe53026309ed1bc4d26626dbaf9b3'] = 'Détails :';
$_LANGPDF['PDF_invoice5bbca5da334d07a677e71b113ca54677'] = 'P.';
$_LANGPDF['PDF_invoice15b57bef332e7e0327d89fe93711a954'] = 'Une version électronique est conservée sur votre compte. Pour y accéder, identifiez-vous sur le site';
$_LANGPDF['PDF_invoiceb1fb57b55075a4a51cf83e44d0440358'] = 'avec vos identifiants (créés lors de votre première commande).';
$_LANGPDF['PDF_invoiced98a07f84921b24ee30f86fd8cd85c3c'] = 'du';
$_LANGPDF['PDF_invoice88be9ea838e21273267409d76af3b284'] = 'Nous avons bien enregistré votre demande de retour.';
$_LANGPDF['PDF_invoicedd0b8feb4eb6c389c284518f5683017c'] = 'Nous vous rappelons que votre colis doit nous être retourné dans les';
$_LANGPDF['PDF_invoiceea62a2e28a800c367509773730120a67'] = 'jours après réception de votre commande.';
$_LANGPDF['PDF_invoice3d2f834cf879baebfdbe52c1c14d9d53'] = 'Liste des produits faisant l\'objet d\'un retour :';
$_LANGPDF['PDF_invoice9fad4fa5f3fa5caad9b506bbdd9f35d4'] = 'Votre n° de retour :';
$_LANGPDF['PDF_invoicefb902bc4807c307b9309f2b528b96f2b'] = 'RET';
$_LANGPDF['PDF_invoiceec9d9f81be48dabb74bcdad5312816af'] = 'Merci de faire figurer ce numéro sur votre colis de retour.';
$_LANGPDF['PDF_invoicefbbd47b7e45c0ad3fe0bf70539b5a2d4'] = 'RAPPEL :';
$_LANGPDF['PDF_invoicea3852e23346f6f1e29e1683991690af3'] = '- Tous les produits doivent être retournés dans leur emballage et leur état d\'origine.';
$_LANGPDF['PDF_invoice0e9a828e54995e48083a072205493fb4'] = '- Veuillez imprimer ce document et le glisser dans votre colis.';
$_LANGPDF['PDF_invoicead500469c8dc258dcebb89c9efe15de7'] = '- Le paquet devra être envoyé à l\'adresse suivante :';
$_LANGPDF['PDF_invoice9f68b11daca41ccf9fdc9d2f69901c9c'] = 'Dès réception de votre colis nous procéderons alors au remboursement du montant de votre commande et vous en informerons par mail.';
$_LANGPDF['PDF_invoice2d0620950a4d96ae301ba7a98e528714'] = 'Merci de nous contacter pour toutes questions.';
$_LANGPDF['PDF_invoice25e12a86579549b9f88117615eb05e4b'] = 'Si les conditions de retour listées ci-dessus n\'étaient pas respectées,';
$_LANGPDF['PDF_invoicec896fe3f3895e8ef54194eec601b8f3c'] = 'nous nous réservons le droit de refuser votre colis ou votre remboursement.';
$_LANGPDF['PDF_invoiceb5a7adde1af5c87d7fd797b6245c2a39'] = 'Description';
$_LANGPDF['PDF_invoice63d5049791d9d79d86e9a108b0a999ca'] = 'Référence';
$_LANGPDF['PDF_invoice03ab340b3f99e03cff9e84314ead38c0'] = 'Qté';
$_LANGPDF['PDF_invoice396124314c5fd1fa5bf463274896dc80'] = 'Pas de méthode d\'affichage de prix défini pour ce groupe d\'utilisateur';
$_LANGPDF['PDF_invoice065ab3a28ca4f16f55f103adc7d0226f'] = 'Livraison';
$_LANGPDF['PDF_invoice6bdf2efe1a99072849d4e87baee37dbe'] = 'Facturation';
$_LANGPDF['PDF_invoice60da3bd6867e3952ef0057a0772ea885'] = 'Numéro d\'indentification fiscale:';
$_LANGPDF['PDF_invoice7b13afd12d6d91d52aa9f857d23f96ef'] = 'Projet de facture';
$_LANGPDF['PDF_invoiced1228f5476d15142b1358ae4b5fa2454'] = 'Commande n°';
$_LANGPDF['PDF_invoicef8617a92ba0a0a4eabee724eab7c9f48'] = 'Transporteur :';
$_LANGPDF['PDF_invoicec1f6368d15f7c13c4e5e8f70c68c747f'] = 'Méthode de paiement :';
$_LANGPDF['PDF_invoicea3a79b28bc45b7fd393effd056b917e1'] = 'Date d\'expédition :';
$_LANGPDF['PDF_invoice115dfa9ced2cf136ae677b9a389a5e60'] = 'Emballage cadeau';
$_LANGPDF['PDF_invoice2370a4958c4ebe6d6c8045cd49a6b392'] = 'Total produits HT';
$_LANGPDF['PDF_invoiceebaee01719541f61281c16ba22ebbfde'] = 'Total produits TTC';
$_LANGPDF['PDF_invoicea0eb2cd0b3deb5444102e9a82edae11e'] = 'Total produits';
$_LANGPDF['PDF_invoicef3e545fccad720e197b9ca3b8b658440'] = 'Totals réductions TTC';
$_LANGPDF['PDF_invoice9cc000efe3e783af5bf114f2e6573156'] = 'Total emballage cadeau';
$_LANGPDF['PDF_invoicef246a17c095de09e043cc1cb917481da'] = 'Total expédition (hors taxes)';
$_LANGPDF['PDF_invoicee93f43fa527c3534aeca987091d6c049'] = 'Total expédition (TTC)';
$_LANGPDF['PDF_invoice96b0141273eabab320119c467cdcaf17'] = 'Total';
$_LANGPDF['PDF_invoice54732c5d0a3f0d597312b0ee55d71fca'] = 'TTC';
$_LANGPDF['PDF_invoiceac5831c7ec2fed92c7bb73e9962003a4'] = 'HT';
$_LANGPDF['PDF_invoiceafd42dfebce46ec93972b2e0cbb8b83f'] = 'Prix unitaire';
$_LANGPDF['PDF_invoice1d744a9ad1dac20645cfc4a36b77323b'] = 'image(s)';
$_LANGPDF['PDF_invoicec2808546f3e14d267d798f4e0e6f102e'] = 'Personnalisé';
$_LANGPDF['PDF_invoicea1e7379abfdbc3b8e03506e5489c6110'] = 'Réduction :';
$_LANGPDF['PDF_invoicee7bbf027179f23c92bec649fa6ae78e4'] = 'Exonéré de la TVA selon l\'article 259B du Code Général des Impôts. ';
$_LANGPDF['PDF_invoice42c26bf38ece1dcd27aca8c6f8c076ed'] = 'Détails de taxe';
$_LANGPDF['PDF_invoice4b78ac8eb158840e9638a3aeb26c4a9d'] = 'Taxe';
$_LANGPDF['PDF_invoicecd6576cc33506a6c44e2debbde5c14d9'] = 'Total HT';
$_LANGPDF['PDF_invoiceb602e0d0c6a72053d0a5be60cb2f8126'] = 'Taxe totale';
$_LANGPDF['PDF_invoicefe1218d355367ae728ae5bf4bbf0019e'] = 'Ecotaxe TTC';
$_LANGPDF['PDF_invoiceae5c2883df7651730799e1036984a6a3'] = 'Total TTC';
$_LANGPDF['PDF_invoice068f80c7519d0528fb08e82137a72131'] = 'Produits';
$_LANGPDF['PDF_invoice914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_LANGPDF['PDF_invoice41c1d61bfff3fc9b1fd8f195061b8caa'] = 'Emballage cadeau';
$_LANGPDF['PDF_invoice6f3455d187a23443796efdcbe044096b'] = 'Aucune taxe';

?>
